@@ -1,11 +1,13 @@
 use bytecursor::ByteCursor;
 use sp_cid::Cid;
 
-use alloc::string::String;
-use sp_std::{
+use alloc::{
+  string::String,
+  vec::Vec
+};
+use core::{
   convert::TryFrom,
   ops::Deref,
-  vec::Vec,
 };
 
 pub struct UnsupportedCodec(pub u64);
